@@ -7,6 +7,7 @@
 # under the terms of the MIT License; see LICENSE file for more details.
 """REANA REST API client."""
 
+import cgi
 import json
 import logging
 import os
@@ -158,18 +159,21 @@ def create_workflow(reana_specification, name, access_token):
 
 
 def create_workflow_from_json(
-    workflow_json,
     name,
     access_token,
+    workflow_json=None,
+    workflow_file=None,
     parameters=None,
     workflow_engine="yadage",
     outputs=None,
 ):
     """Create a workflow from json specification.
 
-    :param workflow_json: workflow specification in json format.
     :param name: name or UUID of the workflow to be started.
     :param access_token: access token of the current user.
+    :param workflow_json: workflow specification in json format.
+    :param workflow_file: workflow specification file path.
+                          Ignores ``workflow_json`` if provided.
     :param parameters: workflow input parameters dictionary.
     :param workflow_engine: one of the workflow engines (yadage, serial, cwl)
     :param outputs: dictionary with expected workflow outputs.
@@ -198,8 +202,11 @@ def create_workflow_from_json(
             "these engines - {}".format(workflow_engine, WORKFLOW_ENGINES)
         )
     try:
-        reana_yaml = {}
-        reana_yaml["workflow"] = {"specification": workflow_json}
+        reana_yaml = dict(workflow={})
+        if workflow_file:
+            reana_yaml["workflow"]["file"] = workflow_file
+        else:
+            reana_yaml["workflow"]["specification"] = workflow_json
         reana_yaml["workflow"]["type"] = workflow_engine
         if parameters:
             reana_yaml["inputs"] = parameters
@@ -357,6 +364,7 @@ def download_file(workflow, file_name, access_token):
     :param workflow: name or id which identifies the workflow.
     :param file_name: file name or path to the file requested.
     :param access_token: access token of the current user.
+    :return: Tuple containing file binary content and filename.
     """
     try:
         from reana_client.utils import get_api_url
@@ -370,8 +378,13 @@ def download_file(workflow, file_name, access_token):
             params={"file_name": file_name, "access_token": access_token},
             verify=False,
         )
+        if "Content-Disposition" in http_response.headers:
+            content_disposition = http_response.headers.get("Content-Disposition")
+            value, params = cgi.parse_header(content_disposition)
+            file_name = params.get("filename", "downloaded_file")
+
         if http_response.status_code == 200:
-            return http_response.content
+            return http_response.content, file_name
         else:
             raise Exception(
                 "Error {status_code} {reason} {message}".format(
@@ -433,11 +446,12 @@ def delete_file(workflow, file_name, access_token):
         raise e
 
 
-def list_files(workflow, access_token, page=None, size=None):
+def list_files(workflow, access_token, file_name=None, page=None, size=None):
     """Return the list of files for a given workflow workspace.
 
     :param workflow: name or id which identifies the workflow.
     :param access_token: access token of the current user.
+    :param file_name: file name(s) (glob) to list.
     :param page: page number of returned file list.
     :param size: page size of returned file list.
     :returns: a list of dictionaries composed by the `name`, `size` and
@@ -447,6 +461,7 @@ def list_files(workflow, access_token, page=None, size=None):
         (response, http_response) = current_rs_api_client.api.get_files(
             workflow_id_or_name=workflow,
             access_token=access_token,
+            file_name=file_name,
             page=page,
             size=size,
         ).result()
