@@ -66,21 +66,24 @@ def files_group(ctx):
     default=None,
     help="Get URLs of output files.",
 )
+@click.argument("filename", metavar="SOURCE", nargs=1, required=False)
 @add_access_token_options
 @add_pagination_options
 @click.pass_context
 def get_files(
-    ctx, workflow, _filter, output_format, access_token, page, size
+    ctx, workflow, _filter, output_format, filename, access_token, page, size
 ):  # noqa: D301
     """List workspace files.
 
     The `ls` command lists workspace files of a workflow specified by the
     environment variable REANA_WORKON or provided as a command-line flag
-    `--workflow` or `-w`.
+    `--workflow` or `-w`. The SOURCE argument is optional and specifies a
+    pattern matching files and directories.
 
     Examples: \n
-    \t $ reana-client ls --workflow myanalysis.42
-    """
+    \t $ reana-client ls --workflow myanalysis.42 \n
+    \t $ reana-client ls --workflow myanalysis.42 'code/\*'
+    """  # noqa: W605
     import tablib
     from reana_client.api.client import current_rs_api_client, list_files
 
@@ -93,7 +96,7 @@ def get_files(
     if workflow:
         logging.info('Workflow "{}" selected'.format(workflow))
         try:
-            response = list_files(workflow, access_token, page, size)
+            response = list_files(workflow, access_token, filename, page, size)
             headers = ["name", "size", "last-modified"]
             data = []
             file_path = get_path_from_operation_id(
@@ -191,7 +194,9 @@ def download_files(
     if workflow:
         for file_name in filenames:
             try:
-                binary_file = download_file(workflow, file_name, access_token)
+                binary_file, file_name = download_file(
+                    workflow, file_name, access_token
+                )
 
                 logging.info(
                     "{0} binary file downloaded ... writing to {1}".format(
